@@ -10,6 +10,7 @@
 
 // own
 #include <config-highscore.h>
+#include <kdegames_highscore_logging.h>
 // KF
 #include <KConfig>
 #include <KConfigGroup>
@@ -29,15 +30,12 @@
 
 #define GROUP "KHighscore"
 
-Q_LOGGING_CATEGORY(GAMES_HIGHSCORE, "org.kde.games.highscore", QtWarningMsg)
-
 class KHighscorePrivate
 {
 public:
-    KHighscorePrivate()
-    {
-    }
+    KHighscorePrivate() = default;
 
+public:
     QString group;
     bool global;
 };
@@ -60,18 +58,20 @@ Q_GLOBAL_STATIC(KHighscoreLockedConfig, lockedConfig)
 
 KHighscore::KHighscore(bool forceLocal, QObject *parent)
     : QObject(parent)
-    , d(new KHighscorePrivate)
+    , d_ptr(new KHighscorePrivate)
 {
     init(forceLocal);
 }
 
 void KHighscore::init(bool forceLocal)
 {
+    Q_D(KHighscore);
+
 #ifdef HIGHSCORE_DIRECTORY
     d->global = !forceLocal;
     if (d->global && lockedConfig->lock == 0) // If we're doing global highscores but not KFileLock has been set up yet
     {
-        qCWarning(GAMES_HIGHSCORE) << "KHighscore::init should be called before!!";
+        qCWarning(KDEGAMES_HIGHSCORE_LOG) << "KHighscore::init should be called before!!";
         abort();
     }
 #else
@@ -83,11 +83,15 @@ void KHighscore::init(bool forceLocal)
 
 bool KHighscore::isLocked() const
 {
+    Q_D(const KHighscore);
+
     return (d->global ? lockedConfig->lock->isLocked() : true);
 }
 
 void KHighscore::readCurrentConfig()
 {
+    Q_D(KHighscore);
+
     if (d->global)
         lockedConfig->config->reparseConfiguration();
 }
@@ -101,19 +105,19 @@ void KHighscore::init(const char *appname)
     /*QFile file(filename);
     if ( !file.open(QIODevice::ReadWrite) )
     {
-      qCWarning(GAMES_HIGHSCORE) << "cannot open global highscore file \""
+      qCWarning(KDEGAMES_HIGHSCORE_LOG) << "cannot open global highscore file \""
                                << filename << "\"";
       abort();
     }*/
 
     /*if (!(QFile::permissions(filename) & QFile::WriteOwner))
       {
-    qCWarning(GAMES_HIGHSCORE) << "cannot write to global highscore file \""
+    qCWarning(KDEGAMES_HIGHSCORE_LOG) << "cannot write to global highscore file \""
                 << filename << "\"";
     abort();
       }*/
 
-    qCDebug(GAMES_HIGHSCORE) << "Global highscore file \"" << filename << "\"";
+    qCDebug(KDEGAMES_HIGHSCORE_LOG) << "Global highscore file \"" << filename << "\"";
     lockedConfig->lock = new QLockFile(filename);
     lockedConfig->config = new KConfig(filename, KConfig::NoGlobals); // read-only   (matt-?)
 
@@ -135,11 +139,11 @@ bool KHighscore::lockForWriting(QWidget *widget)
 
     bool first = true;
     for (;;) {
-        qCDebug(GAMES_HIGHSCORE) << "try locking";
+        qCDebug(KDEGAMES_HIGHSCORE_LOG) << "try locking";
         // lock the highscore file (it should exist)
         int result = lockedConfig->lock->lock();
         bool ok = (result == 0);
-        qCDebug(GAMES_HIGHSCORE) << "locking system-wide highscore file res=" << result << " (ok=" << ok << ")";
+        qCDebug(KDEGAMES_HIGHSCORE_LOG) << "locking system-wide highscore file res=" << result << " (ok=" << ok << ")";
         if (ok) {
             readCurrentConfig();
             return true;
@@ -170,6 +174,8 @@ bool KHighscore::lockForWriting(QWidget *widget)
 
 void KHighscore::writeAndUnlock()
 {
+    Q_D(KHighscore);
+
     if (!d->global) {
         KSharedConfig::openConfig()->sync();
         return;
@@ -177,7 +183,7 @@ void KHighscore::writeAndUnlock()
     if (!isLocked())
         return;
 
-    qCDebug(GAMES_HIGHSCORE) << "unlocking";
+    qCDebug(KDEGAMES_HIGHSCORE_LOG) << "unlocking";
     lockedConfig->config->sync(); // write config
     lockedConfig->lock->unlock();
 }
@@ -189,6 +195,8 @@ KHighscore::~KHighscore()
 
 KConfig *KHighscore::config() const
 {
+    Q_D(const KHighscore);
+
     return (d->global ? lockedConfig->config : static_cast<KConfig *>(KSharedConfig::openConfig().data()));
 }
 
@@ -247,6 +255,9 @@ bool KHighscore::hasEntry(int entry, const QString &key) const
 QStringList KHighscore::readList(const QString &key, int lastEntry) const
 {
     QStringList list;
+    if (lastEntry > 0) {
+        list.reserve(lastEntry);
+    }
     for (int i = 1; hasEntry(i, key) && ((lastEntry > 0) ? (i <= lastEntry) : true); i++) {
         list.append(readEntry(i, key));
     }
@@ -262,11 +273,15 @@ void KHighscore::writeList(const QString &key, const QStringList &list)
 
 void KHighscore::setHighscoreGroup(const QString &group)
 {
+    Q_D(KHighscore);
+
     d->group = group;
 }
 
 QString KHighscore::highscoreGroup() const
 {
+    Q_D(const KHighscore);
+
     return d->group;
 }
 
@@ -290,6 +305,8 @@ QStringList KHighscore::groupList() const
 
 QString KHighscore::group() const
 {
+    Q_D(const KHighscore);
+
     if (highscoreGroup().isEmpty())
         return (d->global ? QString() : QStringLiteral(GROUP));
     return (d->global ? highscoreGroup() : QStringLiteral("%1_%2").arg(QStringLiteral(GROUP), highscoreGroup()));
