@@ -9,8 +9,9 @@
 #include "kscoredialog.h"
 
 // own
-#include "../kgdifficulty.h"
+#include "../kgamedifficulty.h"
 #include "khighscore.h"
+#include <kdegames_highscore_logging.h>
 // KF
 #include <KConfig>
 #include <KLineEdit>
@@ -70,12 +71,14 @@ public:
 
     QDialogButtonBox *buttonBox;
 
+    KScoreDialog *const q;
+
+public:
     // Q-Pointer
-    KScoreDialogPrivate(KScoreDialog *parent)
+    explicit KScoreDialogPrivate(KScoreDialog *parent)
         : q(parent)
     {
     }
-    KScoreDialog *const q;
 
     // Functions
     void loadScores();
@@ -90,8 +93,10 @@ public:
 
 KScoreDialog::KScoreDialog(int fields, QWidget *parent)
     : QDialog(parent)
-    , d(new KScoreDialogPrivate(this))
+    , d_ptr(new KScoreDialogPrivate(this))
 {
+    Q_D(KScoreDialog);
+
     setWindowTitle(i18n("High Scores"));
     setModal(true);
     d->highscoreObject = new KHighscore();
@@ -136,19 +141,15 @@ KScoreDialog::KScoreDialog(int fields, QWidget *parent)
 
 KScoreDialog::~KScoreDialog()
 {
+    Q_D(KScoreDialog);
+
     delete d->highscoreObject;
 }
 
-#if KDEGAMES_BUILD_DEPRECATED_SINCE(4, 1)
-void KScoreDialog::setConfigGroup(const QString &group) // DEPRECATED!
-{
-    d->configGroup = group.toUtf8();
-    d->loaded = false;
-}
-#endif
-
 void KScoreDialog::setConfigGroup(const QPair<QByteArray, QString> &group)
 {
+    Q_D(KScoreDialog);
+
     d->configGroup = group.first; // untranslated string
     addLocalizedConfigGroupName(group); // add the translation to the list
     d->loaded = false;
@@ -156,44 +157,52 @@ void KScoreDialog::setConfigGroup(const QPair<QByteArray, QString> &group)
 
 void KScoreDialog::addLocalizedConfigGroupName(const QPair<QByteArray, QString> &group)
 {
+    Q_D(KScoreDialog);
+
     if (!d->translatedGroupNames.contains(group.first)) {
         d->translatedGroupNames.insert(group.first, group.second);
-        qCDebug(GAMES_HIGHSCORE) << "adding" << group.first << "->" << group.second;
+        qCDebug(KDEGAMES_HIGHSCORE_LOG) << "adding" << group.first << "->" << group.second;
     }
 }
 
 void KScoreDialog::addLocalizedConfigGroupNames(const QMap<QByteArray, QString> &groups)
 {
+    Q_D(KScoreDialog);
+
     QMap<QByteArray, QString>::const_iterator it = groups.begin();
     for (; it != groups.end(); ++it) {
         addLocalizedConfigGroupName(qMakePair(it.key(), it.value()));
     }
 }
 
-void KScoreDialog::initFromDifficulty(const KgDifficulty *diff, bool doSetConfigGroup)
+void KScoreDialog::initFromDifficulty(const KGameDifficulty *diff, bool doSetConfigGroup)
 {
     QMap<QByteArray, QString> localizedLevelStrings;
     QMap<int, QByteArray> levelWeights;
     const auto levels = diff->levels();
-    for (const KgDifficultyLevel *level : levels) {
+    for (const KGameDifficultyLevel *level : levels) {
         localizedLevelStrings.insert(level->key(), level->title());
         levelWeights.insert(level->hardness(), level->key());
     }
     addLocalizedConfigGroupNames(localizedLevelStrings);
     setConfigGroupWeights(levelWeights);
     if (doSetConfigGroup) {
-        const KgDifficultyLevel *curLvl = diff->currentLevel();
+        const KGameDifficultyLevel *curLvl = diff->currentLevel();
         setConfigGroup(qMakePair(curLvl->key(), curLvl->title()));
     }
 }
 
 void KScoreDialog::setHiddenConfigGroups(const QList<QByteArray> &hiddenGroups)
 {
+    Q_D(KScoreDialog);
+
     d->hiddenGroups = hiddenGroups;
 }
 
 void KScoreDialog::setConfigGroupWeights(const QMap<int, QByteArray> &weights)
 {
+    Q_D(KScoreDialog);
+
     d->configGroupWeights = weights;
 }
 
@@ -206,11 +215,15 @@ QString KScoreDialogPrivate::findTranslatedGroupName(const QByteArray &name)
 
 void KScoreDialog::setComment(const QString &comment)
 {
+    Q_D(KScoreDialog);
+
     d->comment = comment;
 }
 
 void KScoreDialog::addField(int field, const QString &header, const QString &key)
 {
+    Q_D(KScoreDialog);
+
     d->fields |= field;
     d->header[field] = header;
     d->key[field] = key;
@@ -218,6 +231,8 @@ void KScoreDialog::addField(int field, const QString &header, const QString &key
 
 void KScoreDialog::hideField(int field)
 {
+    Q_D(KScoreDialog);
+
     d->hiddenFields |= field;
 }
 
@@ -333,7 +348,7 @@ void KScoreDialogPrivate::aboutToShow()
         const QByteArray &groupKey = it.key();
         if (hiddenGroups.contains(groupKey))
             continue;
-        qCDebug(GAMES_HIGHSCORE) << latest.first << tabWidget->tabText(tabIndex);
+        qCDebug(KDEGAMES_HIGHSCORE_LOG) << latest.first << tabWidget->tabText(tabIndex);
 
         // Only display the comment on the page with the new score (or) this one if there's only one tab
         if (latest.first == groupKey || (latest.first.isEmpty() && groupKey == "High Scores")) {
@@ -367,7 +382,7 @@ void KScoreDialogPrivate::aboutToShow()
             QLabel *label;
             num.setNum(i);
 
-            // qCDebug(GAMES_HIGHSCORE) << "groupName:" << groupName << "id:" << i-1;
+            // qCDebug(KDEGAMES_HIGHSCORE_LOG) << "groupName:" << groupName << "id:" << i-1;
 
             KScoreDialog::FieldInfo score = scores[groupKey].at(i - 1);
             label = labels[groupKey].at((i - 1) * nrCols + 0); // crash! FIXME
@@ -429,7 +444,7 @@ void KScoreDialogPrivate::loadScores()
 
     if (!groupKeyList.contains(configGroup)) // If the current group doesn't have any entries, add it to the list to process
     {
-        qCDebug(GAMES_HIGHSCORE) << "The current high score group " << configGroup << " isn't in the list, adding it";
+        qCDebug(KDEGAMES_HIGHSCORE_LOG) << "The current high score group " << configGroup << " isn't in the list, adding it";
         groupKeyList << configGroup;
         setupGroup(configGroup);
     }
@@ -452,7 +467,7 @@ void KScoreDialogPrivate::loadScores()
     const auto groupKeys = scores.keys();
     for (const QByteArray &groupKey : groupKeys) {
         if ((scores[groupKey][0].value(KScoreDialog::Score) == QLatin1String("-")) && (scores.size() > 1) && (latest.first != groupKey)) {
-            qCDebug(GAMES_HIGHSCORE) << "Removing group " << groupKey << " since it's unused.";
+            qCDebug(KDEGAMES_HIGHSCORE_LOG) << "Removing group " << groupKey << " since it's unused.";
             scores.remove(groupKey);
         }
     }
@@ -476,9 +491,11 @@ void KScoreDialogPrivate::saveScores()
     highscoreObject->writeAndUnlock();
 }
 
-int KScoreDialog::addScore(const FieldInfo &newInfo, const AddScoreFlags &flags)
+int KScoreDialog::addScore(const FieldInfo &newInfo, AddScoreFlags flags)
 {
-    qCDebug(GAMES_HIGHSCORE) << "adding new score";
+    Q_D(KScoreDialog);
+
+    qCDebug(KDEGAMES_HIGHSCORE_LOG) << "adding new score";
 
     bool askName = false, lessIsMore = false;
     if (flags.testFlag(KScoreDialog::AskName))
@@ -499,7 +516,7 @@ int KScoreDialog::addScore(const FieldInfo &newInfo, const AddScoreFlags &flags)
         score = FieldInfo(newInfo); // now look at the submitted score
         int newScore = score[Score].toInt();
 
-        qCDebug(GAMES_HIGHSCORE) << "num_score =" << num_score << " - newScore =" << newScore;
+        qCDebug(KDEGAMES_HIGHSCORE_LOG) << "num_score =" << num_score << " - newScore =" << newScore;
 
         if (((newScore > num_score) && !lessIsMore) || ((newScore < num_score) && lessIsMore) || !ok) {
             d->latest = QPair<QByteArray, int>(d->configGroup, i + 1);
@@ -549,7 +566,7 @@ int KScoreDialog::addScore(const FieldInfo &newInfo, const AddScoreFlags &flags)
     return 0;
 }
 
-int KScoreDialog::addScore(int newScore, const AddScoreFlags &flags)
+int KScoreDialog::addScore(int newScore, AddScoreFlags flags)
 {
     FieldInfo scoreInfo;
     scoreInfo[Score] = QString::number(newScore);
@@ -558,12 +575,16 @@ int KScoreDialog::addScore(int newScore, const AddScoreFlags &flags)
 
 void KScoreDialog::show()
 {
+    Q_D(KScoreDialog);
+
     d->aboutToShow();
     QDialog::show();
 }
 
 int KScoreDialog::exec()
 {
+    Q_D(KScoreDialog);
+
     d->aboutToShow();
     return QDialog::exec();
 }
@@ -576,6 +597,8 @@ void KScoreDialog::slotGotReturn()
 
 void KScoreDialog::slotGotName()
 {
+    Q_D(KScoreDialog);
+
     if (d->newName.second == -1)
         return;
 
@@ -605,6 +628,8 @@ void KScoreDialog::slotGotName()
 
 void KScoreDialog::slotForgetScore()
 {
+    Q_D(KScoreDialog);
+
     if (d->newName.second == -1)
         return;
     // remove the editor from the stack
@@ -625,6 +650,8 @@ void KScoreDialog::slotForgetScore()
 
 int KScoreDialog::highScore()
 {
+    Q_D(KScoreDialog);
+
     if (!d->loaded)
         d->loadScores();
 
@@ -636,6 +663,8 @@ int KScoreDialog::highScore()
 
 void KScoreDialog::keyPressEvent(QKeyEvent *ev)
 {
+    Q_D(KScoreDialog);
+
     if ((d->newName.second != -1) && (ev->key() == Qt::Key_Return)) {
         ev->ignore();
         return;
