@@ -10,14 +10,14 @@
 // own
 #include "colorproxy_p.h"
 #include "kgamerendererclient.h"
-#include "kgtheme.h"
-#include "kgthemeprovider.h"
+#include "kgametheme.h"
+#include "kgamethemeprovider.h"
+#include <kdegames_logging.h>
 // Qt
 #include <QDateTime>
 #include <QFileInfo>
 #include <QGuiApplication>
 #include <QPainter>
-#include <QScopedPointer>
 #include <QVariant>
 
 // TODO: automatically schedule pre-rendering of animation frames
@@ -27,55 +27,53 @@ static const QString cacheName(QByteArray theme)
 {
     const QString appName = QCoreApplication::instance()->applicationName();
     // e.g. "themes/foobar.desktop" -> "themes/foobar"
-    if (theme.endsWith(QByteArray(".desktop")))
+    if (theme.endsWith(QByteArrayLiteral(".desktop")))
         theme.chop(8); // 8 = strlen(".desktop")
     return QStringLiteral("kgamerenderer-%1-%2").arg(appName, QString::fromUtf8(theme));
 }
 
-KGameRendererPrivate::KGameRendererPrivate(KgThemeProvider *provider, unsigned cacheSize, KGameRenderer *parent)
+KGameRendererPrivate::KGameRendererPrivate(KGameThemeProvider *provider, unsigned cacheSize, KGameRenderer *parent)
     : m_parent(parent)
     , m_provider(provider)
-    , m_currentTheme(nullptr) // will be loaded on first use
     , m_frameSuffix(QStringLiteral("_%1"))
     , m_sizePrefix(QStringLiteral("%1-%2-"))
     , m_frameCountPrefix(QStringLiteral("fc-"))
     , m_boundsPrefix(QStringLiteral("br-"))
     // default cache size: 3 MiB = 3 << 20 bytes
     , m_cacheSize((cacheSize == 0 ? 3 : cacheSize) << 20)
-    , m_strategies(KGameRenderer::UseDiskCache | KGameRenderer::UseRenderingThreads)
-    , m_frameBaseIndex(0)
-    , m_defaultPrimaryView(nullptr)
     , m_rendererPool(&m_workerPool)
-    , m_imageCache(nullptr)
 {
     qRegisterMetaType<KGRInternal::Job *>();
 }
 
-KGameRenderer::KGameRenderer(KgThemeProvider *provider, unsigned cacheSize)
-    : d(new KGameRendererPrivate(provider, cacheSize, this))
+KGameRenderer::KGameRenderer(KGameThemeProvider *provider, unsigned cacheSize)
+    : d_ptr(new KGameRendererPrivate(provider, cacheSize, this))
 {
     if (!provider->parent()) {
         provider->setParent(this);
     }
-    connect(provider, &KgThemeProvider::currentThemeChanged, this, [this](const KgTheme *theme) {
+    connect(provider, &KGameThemeProvider::currentThemeChanged, this, [this](const KGameTheme *theme) {
+        Q_D(KGameRenderer);
         d->_k_setTheme(theme);
     });
 }
 
-static KgThemeProvider *providerForSingleTheme(KgTheme *theme, QObject *parent)
+static KGameThemeProvider *providerForSingleTheme(KGameTheme *theme, QObject *parent)
 {
-    KgThemeProvider *prov = new KgThemeProvider(QByteArray(), parent);
+    KGameThemeProvider *prov = new KGameThemeProvider(QByteArray(), parent);
     prov->addTheme(theme);
     return prov;
 }
 
-KGameRenderer::KGameRenderer(KgTheme *theme, unsigned cacheSize)
-    : d(new KGameRendererPrivate(providerForSingleTheme(theme, this), cacheSize, this))
+KGameRenderer::KGameRenderer(KGameTheme *theme, unsigned cacheSize)
+    : d_ptr(new KGameRendererPrivate(providerForSingleTheme(theme, this), cacheSize, this))
 {
 }
 
 KGameRenderer::~KGameRenderer()
 {
+    Q_D(KGameRenderer);
+
     // cleanup clients
     while (!d->m_clients.isEmpty()) {
         delete d->m_clients.constBegin().key();
@@ -85,43 +83,45 @@ KGameRenderer::~KGameRenderer()
     delete d->m_imageCache;
 }
 
-QGraphicsView *KGameRenderer::defaultPrimaryView() const
-{
-    return d->m_defaultPrimaryView;
-}
-
-void KGameRenderer::setDefaultPrimaryView(QGraphicsView *view)
-{
-    d->m_defaultPrimaryView = view;
-}
-
 int KGameRenderer::frameBaseIndex() const
 {
+    Q_D(const KGameRenderer);
+
     return d->m_frameBaseIndex;
 }
 
 void KGameRenderer::setFrameBaseIndex(int frameBaseIndex)
 {
+    Q_D(KGameRenderer);
+
     d->m_frameBaseIndex = frameBaseIndex;
 }
 
 QString KGameRenderer::frameSuffix() const
 {
+    Q_D(const KGameRenderer);
+
     return d->m_frameSuffix;
 }
 
 void KGameRenderer::setFrameSuffix(const QString &suffix)
 {
+    Q_D(KGameRenderer);
+
     d->m_frameSuffix = suffix.contains(QLatin1String("%1")) ? suffix : QStringLiteral("_%1");
 }
 
 KGameRenderer::Strategies KGameRenderer::strategies() const
 {
+    Q_D(const KGameRenderer);
+
     return d->m_strategies;
 }
 
 void KGameRenderer::setStrategyEnabled(KGameRenderer::Strategy strategy, bool enabled)
 {
+    Q_D(KGameRenderer);
+
     const bool oldEnabled = d->m_strategies & strategy;
     if (enabled) {
         d->m_strategies |= strategy;
@@ -130,7 +130,7 @@ void KGameRenderer::setStrategyEnabled(KGameRenderer::Strategy strategy, bool en
     }
     if (strategy == KGameRenderer::UseDiskCache && oldEnabled != enabled) {
         // reload theme
-        const KgTheme *theme = d->m_currentTheme;
+        const KGameTheme *theme = d->m_currentTheme;
         if (theme) {
             d->m_currentTheme = nullptr; // or setTheme() will return immediately
             d->_k_setTheme(theme);
@@ -138,17 +138,17 @@ void KGameRenderer::setStrategyEnabled(KGameRenderer::Strategy strategy, bool en
     }
 }
 
-void KGameRendererPrivate::_k_setTheme(const KgTheme *theme)
+void KGameRendererPrivate::_k_setTheme(const KGameTheme *theme)
 {
-    const KgTheme *oldTheme = m_currentTheme;
+    const KGameTheme *oldTheme = m_currentTheme;
     if (oldTheme == theme) {
         return;
     }
-    qCDebug(GAMES_LIB) << "Setting theme:" << theme->name();
+    qCDebug(KDEGAMES_LOG) << "Setting theme:" << theme->name();
     if (!setTheme(theme)) {
-        const KgTheme *defaultTheme = m_provider->defaultTheme();
+        const KGameTheme *defaultTheme = m_provider->defaultTheme();
         if (theme != defaultTheme) {
-            qCDebug(GAMES_LIB) << "Falling back to default theme:" << defaultTheme->name();
+            qCDebug(KDEGAMES_LOG) << "Falling back to default theme:" << defaultTheme->name();
             setTheme(defaultTheme);
             m_provider->setCurrentTheme(defaultTheme);
         }
@@ -157,19 +157,19 @@ void KGameRendererPrivate::_k_setTheme(const KgTheme *theme)
     QHash<KGameRendererClient *, QString>::iterator it1 = m_clients.begin(), it2 = m_clients.end();
     for (; it1 != it2; ++it1) {
         it1.value().clear(); // because the pixmap is outdated
-        it1.key()->d->fetchPixmap();
+        it1.key()->d_ptr->fetchPixmap();
     }
     Q_EMIT m_parent->themeChanged(m_currentTheme);
 }
 
-bool KGameRendererPrivate::setTheme(const KgTheme *theme)
+bool KGameRendererPrivate::setTheme(const KGameTheme *theme)
 {
     if (!theme) {
         return false;
     }
     // open cache (and SVG file, if necessary)
     if (m_strategies & KGameRenderer::UseDiskCache) {
-        QScopedPointer<KImageCache> oldCache(m_imageCache);
+        std::unique_ptr<KImageCache> oldCache(m_imageCache);
         const QString imageCacheName = cacheName(theme->identifier());
         m_imageCache = new KImageCache(imageCacheName, m_cacheSize);
         m_imageCache->setPixmapCaching(false); // see big comment in KGRPrivate class declaration
@@ -184,10 +184,10 @@ bool KGameRendererPrivate::setTheme(const KgTheme *theme)
         // FIXME: This logic breaks if the cache evicts the "kgr_timestamp" key. We need additional API in KSharedDataCache to make sure that this key does not
         // get evicted.
         if (cacheTimestamp < svgTimestamp) {
-            qCDebug(GAMES_LIB) << "Theme newer than cache, checking SVG";
-            QScopedPointer<QSvgRenderer> renderer(new QSvgRenderer(theme->graphicsPath()));
+            qCDebug(KDEGAMES_LOG) << "Theme newer than cache, checking SVG";
+            std::unique_ptr<QSvgRenderer> renderer(new QSvgRenderer(theme->graphicsPath()));
             if (renderer->isValid()) {
-                m_rendererPool.setPath(theme->graphicsPath(), renderer.take());
+                m_rendererPool.setPath(theme->graphicsPath(), renderer.release());
                 m_imageCache->clear();
                 m_imageCache->insert(QStringLiteral("kgr_timestamp"), QByteArray::number(svgTimestamp));
             } else {
@@ -195,8 +195,8 @@ bool KGameRendererPrivate::setTheme(const KgTheme *theme)
                 // breaking the previous theme.
                 delete m_imageCache;
                 KSharedDataCache::deleteCache(imageCacheName);
-                m_imageCache = oldCache.take();
-                qCDebug(GAMES_LIB) << "Theme change failed: SVG file broken";
+                m_imageCache = oldCache.release();
+                qCDebug(KDEGAMES_LOG) << "Theme change failed: SVG file broken";
                 return false;
             }
         }
@@ -206,11 +206,11 @@ bool KGameRendererPrivate::setTheme(const KgTheme *theme)
     } else // !(m_strategies & KGameRenderer::UseDiskCache) -> no cache is used
     {
         // load SVG file
-        QScopedPointer<QSvgRenderer> renderer(new QSvgRenderer(theme->graphicsPath()));
+        std::unique_ptr<QSvgRenderer> renderer(new QSvgRenderer(theme->graphicsPath()));
         if (renderer->isValid()) {
-            m_rendererPool.setPath(theme->graphicsPath(), renderer.take());
+            m_rendererPool.setPath(theme->graphicsPath(), renderer.release());
         } else {
-            qCDebug(GAMES_LIB) << "Theme change failed: SVG file broken";
+            qCDebug(KDEGAMES_LOG) << "Theme change failed: SVG file broken";
             return false;
         }
         // disconnect from disk cache (only needed if changing strategy)
@@ -226,17 +226,21 @@ bool KGameRendererPrivate::setTheme(const KgTheme *theme)
     return true;
 }
 
-const KgTheme *KGameRenderer::theme() const
+const KGameTheme *KGameRenderer::theme() const
 {
+    Q_D(const KGameRenderer);
+
     // ensure that some theme is loaded
     if (!d->m_currentTheme) {
-        d->_k_setTheme(d->m_provider->currentTheme());
+        const_cast<KGameRendererPrivate *>(d)->_k_setTheme(d->m_provider->currentTheme());
     }
     return d->m_currentTheme;
 }
 
-KgThemeProvider *KGameRenderer::themeProvider() const
+KGameThemeProvider *KGameRenderer::themeProvider() const
 {
+    Q_D(const KGameRenderer);
+
     return d->m_provider;
 }
 
@@ -261,9 +265,11 @@ QString KGameRendererPrivate::spriteFrameKey(const QString &key, int frame, bool
 
 int KGameRenderer::frameCount(const QString &key) const
 {
+    Q_D(const KGameRenderer);
+
     // ensure that some theme is loaded
     if (!d->m_currentTheme) {
-        d->_k_setTheme(d->m_provider->currentTheme());
+        const_cast<KGameRendererPrivate *>(d)->_k_setTheme(d->m_provider->currentTheme());
     }
     // look up in in-process cache
     QHash<QString, int>::const_iterator it = d->m_frameCountCache.constFind(key);
@@ -308,10 +314,12 @@ int KGameRenderer::frameCount(const QString &key) const
 
 QRectF KGameRenderer::boundsOnSprite(const QString &key, int frame) const
 {
+    Q_D(const KGameRenderer);
+
     const QString elementKey = d->spriteFrameKey(key, frame);
     // ensure that some theme is loaded
     if (!d->m_currentTheme) {
-        d->_k_setTheme(d->m_provider->currentTheme());
+        const_cast<KGameRendererPrivate *>(d)->_k_setTheme(d->m_provider->currentTheme());
     }
     // look up in in-process cache
     QHash<QString, QRectF>::const_iterator it = d->m_boundsCache.constFind(elementKey);
@@ -351,13 +359,17 @@ QRectF KGameRenderer::boundsOnSprite(const QString &key, int frame) const
 
 bool KGameRenderer::spriteExists(const QString &key) const
 {
+    Q_D(const KGameRenderer);
+
     return this->frameCount(key) >= 0;
 }
 
-QPixmap KGameRenderer::spritePixmap(const QString &key, const QSize &size, int frame, const QHash<QColor, QColor> &customColors) const
+QPixmap KGameRenderer::spritePixmap(const QString &key, QSize size, int frame, const QHash<QColor, QColor> &customColors) const
 {
+    Q_D(const KGameRenderer);
+
     QPixmap result;
-    d->requestPixmap(KGRInternal::ClientSpec(key, frame, size, customColors), nullptr, &result);
+    const_cast<KGameRendererPrivate *>(d)->requestPixmap(KGRInternal::ClientSpec(key, frame, size, customColors), nullptr, &result);
     return result;
 }
 
@@ -483,28 +495,24 @@ static const uint transparentRgba = QColor(Qt::transparent).rgba();
 void KGRInternal::Worker::run()
 {
     QImage image(m_job->spec.size, QImage::Format_ARGB32_Premultiplied);
-    // image might not be created if size is too large for needed memory, or invalid
-    if (image.isNull()) {
-        qCWarning(GAMES_LIB) << "Could not create QImage. Key:" << m_job->spec.spriteKey << "Frame:" << m_job->spec.frame << "Size:" << m_job->spec.size;
+    image.fill(transparentRgba);
+    QPainter *painter = nullptr;
+    QPaintDeviceColorProxy *proxy = nullptr;
+    // if no custom colors requested, paint directly onto image
+    if (m_job->spec.customColors.isEmpty()) {
+        painter = new QPainter(&image);
     } else {
-        image.fill(transparentRgba);
-        QPainter *painter = nullptr;
-        QPaintDeviceColorProxy *proxy = nullptr;
-        // if no custom colors requested, paint directly onto image
-        if (m_job->spec.customColors.isEmpty()) {
-            painter = new QPainter(&image);
-        } else {
-            proxy = new QPaintDeviceColorProxy(&image, m_job->spec.customColors);
-            painter = new QPainter(proxy);
-        }
-
-        // do renderering
-        QSvgRenderer *renderer = m_job->rendererPool->allocRenderer();
-        renderer->render(painter, m_job->elementKey);
-        m_job->rendererPool->freeRenderer(renderer);
-        delete painter;
-        delete proxy;
+        proxy = new QPaintDeviceColorProxy(&image, m_job->spec.customColors);
+        painter = new QPainter(proxy);
     }
+
+    // do renderering
+    QSvgRenderer *renderer = m_job->rendererPool->allocRenderer();
+    renderer->render(painter, m_job->elementKey);
+    m_job->rendererPool->freeRenderer(renderer);
+    delete painter;
+    delete proxy;
+
     // talk back to the main thread
     m_job->result = image;
     QMetaObject::invokeMethod(m_parent, "jobFinished", Qt::AutoConnection, Q_ARG(KGRInternal::Job *, m_job), Q_ARG(bool, m_synchronous));
